##### Libraries for analyses #####
library(adegenet)
library(betareg)
library(DESeq2)
library(dplyr)
library(ellipse)
library(EnhancedVolcano)
library(extrafont)
library(GenomicRanges)
library(ggplot2)
library(gridExtra)
library(karyoploteR)
library(mclust)
library(missMDA)
library(pcaMethods)
library(plotrix)
library(RColorBrewer)
library(readxl)
library(stringr)
library(tidyr)
library(tidyverse)
library(viridis)

########################### COLOUR ANALYSIS GENETIC BASIS ############################
############# PHENOTYPIC ANALYSIS #############
setwd("C:/Users/hans_/Dropbox/Elmer Lab/Projects/Zootoca_colouration/06_re-submission_Mol_Ecol/R2_resubmission/enlighten")
# females used in colour mapping and SD-corrected Q values for hybrids
dots <- read.table("phenotypes_sex_qvalue_females_Q_CI_final.txt", header=T)
# setup up colours for the two modes and hybrids
parity_col <- c("#CECECE", "#F78B14")
parity_hyb_col <- c("#CECECE","#F9ED62", "#F78B14")
par(mfrow=c(1,1))
###### PCA of colour phenotypes ###### 
# use updated parity modes with corrected Q-values
data <- read.table("PCA_scores_colour_Q_corr.txt", header = T)
dim(data)
par(mfrow=c(1,1))
cols <- c(5,9:11)
forPCA <- data[,cols]
zootoca.PCA <- prcomp(na.omit(forPCA),scale=FALSE)
str (zootoca.PCA)
plot(zootoca.PCA)
biplot(zootoca.PCA, choices = 3:2)
summary(zootoca.PCA)
zootoca.PCA$rotation
#write.table(zootoca.PCA$x, "PCA_scores_colour_Q_corr.txt", sep="\t")
zootoca.PCA$scale
zootoca.PCA$rotation
#write.table(zootoca.PCA$rotation, "PCA_rotation.txt", sep="\t")

### FIGURE 1 ###
# plot sex and mode (hybrids = 1%-99% admixture)
dots$sex_mode <- factor(dots$sex_mode, levels=c("egg", "hybrid","live"))
boxplot(prop~sex_mode,data=dots, col=parity_hyb_col, ylab="Proportion of belly dotted")
boxplot(dots~sex_mode,data=dots, col=parity_hyb_col, ylab="Number of dots")
boxplot(h~sex_mode,data=dots, col=parity_hyb_col, ylab="Hue", ylim=c(10,60))
boxplot(s~sex_mode,data=dots, col=parity_hyb_col, ylab="Saturation", ylim=c(10,110))
boxplot(l~sex_mode,data=dots, col=parity_hyb_col, ylab="Lightness", ylim=c(20,100))
# plot PCA and PC2
data <- read.table("PCA_scores_colour_Q_corr.txt", header = T)
females <- subset(data, sex=="female")
sp_f1<-ggplot(females, aes(x=PC1_col_dots, y=PC2_col_dots, color=sex_mode)) +geom_point(aes(shape = sex_mode, color = sex_mode), size = 2) +
  stat_ellipse(aes(x=PC1_col_dots, y=PC2_col_dots,color=sex_mode),level = 0.75,type = "norm") + 
  theme_classic()
sp_f <- sp_f1 + scale_color_manual(values=c("#F9ED62", "#CECECE", "#F78B14"))
sp_f
# violin plot of PC2
data$sex_mode <- factor(data$sex_mode, levels=c("oviparous", "hybrid", "viviparous"))
p1 <- ggplot(data, aes(x=sex_mode, y=PC2_col_dots, fill = sex_mode)) +
  geom_violin(trim=FALSE) + ylim(-50,40) +
  geom_boxplot(width=0.1) 
p1 + scale_fill_manual(values=c("#CECECE", "#F9ED62", "#F78B14"))

### TABLE S1 ###
#calculate averages & errors
dots <- read.table("phenotypes_sex_qvalue_females_Q_CI_final.txt", header=T)
str(dots)
dim(dots$mode)
dots %>% group_by(mode) %>% summarise(average = mean(prop, na.rm = TRUE), error = std.error(prop, na.rm = TRUE))
dots %>% group_by(mode) %>% summarise(average = mean(dots, na.rm = TRUE), error = std.error(dots, na.rm = TRUE))
dots %>% group_by(mode) %>% summarise(average = mean(h, na.rm = TRUE), error = std.error(h, na.rm = TRUE))
dots %>% group_by(mode) %>% summarise(average = mean(s, na.rm = TRUE), error = std.error(s, na.rm = TRUE))
dots %>% group_by(mode) %>% summarise(average = mean(l, na.rm = TRUE), error = std.error(l, na.rm = TRUE))
# statistics
## Proprotion of spots with beta regression
summary(a1<-(glm(prop~mode,data=dots)))
summary(betareg(a1<-prop_trans~mode,data=dots, na.action = na.omit,link = "logit"))
## number of spots wih glm and quasipoisson followed by anova
summary(a2<-(glm(dots~mode,data=dots,family="quasipoisson")))
hist(a2$residuals)
anova(a2, test="F")
## colouration variables with glm followed by anova
summary(a3<-(glm(h~mode,data=dots)))
anova(a3, test="F")
summary(a4<-(glm(s~mode,data=dots)))
anova(a4, test="F")
summary(a5<-(glm(l~mode,data=dots)))
anova(a5, test="F")

### FIGURE S1 ###
## load PCA data but only pure modes, excluding hybrids
data <- read.table("PCA_scores_colour_Pure_modes_Q_corr.txt", header=T)
dim(data)
str(data)
# Clustering
par(mfrow=c(1,1))
mod1 <- Mclust(data[,6:8])
summary(mod1)
plot(mod1, what = c("BIC", "classification"))
mod1$BIC
mod2 <- Mclust(data[,19:21])
summary(mod2)
plot(mod2, what = c("BIC", "classification"))
mod2$BIC
mclustBootstrapLRT(data[,6:8],modelName="EEV")
mclustBootstrapLRT(data[,19:21],modelName="EEV")
# compare clsuters to real category
str(data)
table(data$sex_mode, mod1$classification)
table(data$sex_mode, mod2$classification)
adjustedRandIndex(data$mode, mod1$classification)
adjustedRandIndex(data$mode, mod2$classification)

###### REPEATABILITY ###### 
### check if colouration is repeatbale trait ###
repeats <- read.table("repeats_2018_clean_PCA_females.txt", header=T)
str(repeats)
# do PCA with imputed values for dots (added as new column to data sheet)
par(mfrow=c(1,1))
cols <- c(18:20)
forPCA <- repeats[,cols]
zootoca.PCA <- prcomp(na.omit(forPCA),scale=FALSE)
str (zootoca.PCA)
plot(zootoca.PCA)
biplot(zootoca.PCA, choices = 3:2)
summary(zootoca.PCA)
zootoca.PCA$rotation
#write.table(zootoca.PCA$x, "PCA_scores_colour_dots.txt", sep="\t")
zootoca.PCA$scale
zootoca.PCA$rotation
#write.table(zootoca.PCA$rotation, "PCA_rotation.txt", sep="\t")
# add PCA columns to dataframe
repeats_PCA <- cbind(repeats,zootoca.PCA$x)
str(repeats_PCA)
# some basic plots
repeats_PCA$repeat_week <-as.character(repeats_PCA$repeat_week)
repeats_PCA$repeat_day <-as.character(repeats_PCA$repeat_day)
#write.table(repeats_PCA,"repeats_2018_clean_PCA_females.txt")
#read in file with PCA
repeats_PCA <- read.table("repeats_2018_clean_PCA_females.txt", header=T)
repeats_PCA$ELT <- factor(repeats_PCA$ELT,levels=c("ELT09304", "ELT09386", "ELT09357", "ELT09367", "ELT09480", "ELT09298", "ELT09391", "ELT09513", "ELT09350", "ELT09375", "ELT09444"))
repeats_PCA$parity_mode <- factor(repeats_PCA$parity_mode,levels=c("oviparous", "viviparous")) 

### TABLE S2 ###
## calculate the proportion explained by the different variables ##
## within females
# PC1
mod1<-(aov(PC1~parity_mode+ELT+repeat_week+repeat_day, data=repeats_PCA))
af <- anova(mod1)
afss <- af$"Sum Sq"
print(cbind(af,PctExp=afss/sum(afss)*100))
# Hue
mod1<-(aov(H~parity_mode+ELT+repeat_week+repeat_day, data=repeats_PCA))
af <- anova(mod1)
afss <- af$"Sum Sq"
print(cbind(af,PctExp=afss/sum(afss)*100))
# Saturation
mod1<-(aov(S~parity_mode+ELT+repeat_week+repeat_day, data=repeats_PCA))
af <- anova(mod1)
afss <- af$"Sum Sq"
print(cbind(af,PctExp=afss/sum(afss)*100))
# Lightness
mod1<-(aov(L~parity_mode+ELT+repeat_week+repeat_day, data=repeats_PCA))
af <- anova(mod1)
afss <- af$"Sum Sq"
print(cbind(af,PctExp=afss/sum(afss)*100))

################### ADMIXTURE & COLOUR GENETICS ################### 
par(mfrow=c(1,1))
setwd("C:/Users/hans_/Dropbox/Elmer Lab/Projects/Zootoca_colouration/06_re-submission_Mol_Ecol/R2_resubmission/enlighten")
# use new table with corrected Q values
admix <-read.table("phenotypes_sex_qvalue_females_Q_CI_final.txt",header=T)
str(admix)

### FIGURE 2 ###
## admixture plot ## 
admix <-read.table("phenotypes_sex_qvalue_females_Q_CI_final.txt",header=T)
str(admix)
data <- admix[,15:16]
parity_col <- c("#CECECE","#F78B14")
barplot(t(as.matrix(data)), col=parity_col,
        xlab="Individual #", ylab="Ancestry", names=data$sex_mode, border=NA,las=2)
### ventral colour ### 
## display data with updated chromosome names
params <-read.table("mlm_female_colour_p_adjust_19chr_re-ordered.txt",header=T)
chromo_vec <-scan("chrs.txt")
length_vec <-scan("chr_lengths_new.txt")
# load candidate regions for parity mode
regions <- read.table("updated_cand_regions.txt", header=TRUE)
str(regions)
cand.regions <-GRanges(seqnames = regions$chrLG, ranges = regions$range)
# Plot candidate SNPS colour
str(params)
snps <- GRanges(seqnames = params$chr,ranges = IRanges(params$ps, width = 1), y=params$LogP)
# set colors
by_chr <- c("gray40", "gray80")
#plot chromosomes
kp <- plotKaryotype(genome=data.frame(chromo_vec, length_vec),plot.type = 4)
# plot SNP p-values
kpAxis(kp, ymin = 0, ymax = 10, numticks = 11, col="#666666", cex=1, r0=0, r1=1)
kpPoints(kp, data=snps,col=colByChr(snps,by_chr), pch=16, cex=0.75, ymax=10, r0=0, r1=1)
## Zoom into candidate chromosome 5 DGAT2 ##
kp<- plotKaryotype(genome=data.frame(chromo_vec, length_vec),chromosomes = c("5"), plot.type = 4)
kpAddBaseNumbers(kp, add.units = TRUE, cex=1, tick.dist = 10000000)
kpAxis(kp, ymin = 0, ymax = 10, numticks = 11, col="#666666", cex=1, r0=0, r1=0.8)
kpPoints(kp, data=snps,col=colByChr(snps,by_chr), pch=16, cex=0.75, ymin=0, ymax=10, r0=0, r1=0.8)
kpAbline(kp,  h=0.5, r0=0, r1=0.8, col="firebrick3",lty=2)
# plot regions
kpRect(kp, data= cand.regions, y0=0, y1=1, col="coral3", border=NA, r0=0, r1=0.8)
kpPlotDensity(kp, data=snps, col="lightskyblue1", r0=0.82, window.size = 1000000)
kpAddLabels(kp, labels = "Density", srt=90, pos=3, cex=0.8, label.margin = 0.025, r0=0.82)
## Zoom into candidate chromosome 2 PMEL ##
kp<- plotKaryotype(genome=data.frame(chromo_vec, length_vec),chromosomes = c("2"), plot.type = 4)
kpAddBaseNumbers(kp, add.units = TRUE, cex=1, tick.dist = 10000000)
kpAxis(kp, ymin = 0, ymax = 10, numticks = 11, col="#666666", cex=1, r0=0, r1=0.8)
kpPoints(kp, data=snps,col=colByChr(snps,by_chr), pch=16, cex=0.75, ymax=10, r0=0, r1=0.8)
kpAbline(kp,  h=0.5, r0=0, r1=0.8, col="firebrick3",lty=2)
# plot regions
kpRect(kp, data= cand.regions, y0=0, y1=1, col="coral3", border=NA, r0=0, r1=0.8)
kpPlotDensity(kp, data=snps, col="lightskyblue1", r0=0.82, window.size = 1000000)
kpAddLabels(kp, labels = "Density", srt=90, pos=3, cex=0.8, label.margin = 0.025, r0=0.82)
### dots ###
params <-read.table("mlm_female_dots_p_adjust_19chr_re-ordered.txt",header=T)
str(params)
# Plot candidate SNPS dots
snps <- GRanges(seqnames = params$chr,ranges = IRanges(params$ps, width = 1), y=params$LogP)
#plot chromosomes
kp <- plotKaryotype(genome=data.frame(chromo_vec, length_vec),plot.type = 4)
# plot SNP p-values
kpAxis(kp, ymin = 0, ymax = 10, numticks = 11, col="#666666", cex=1, r0=0, r1=1)
kpPoints(kp, data=snps,col=colByChr(snps,by_chr), pch=16, cex=0.75, ymax=10, r0=0, r1=1)

### FIGURE S3 ###
## test if SNPS are under selection
sel <- read.table("colour_vs_selection_scores.txt", header=T)
str(sel)
ggplot(sel, aes(x=pcadapt_LogP, y=LogP)) + geom_hline(yintercept=5, linetype="dashed", color = "red") +
	geom_point() + geom_vline (xintercept=5, linetype="dashed", color = "red") + theme_classic()

### Parity mode vs colour genes ###
## test if candidate SNP closer to parity mode genes than expected by chance ##
par(mfrow=c(1,1))
ran<-read.table("random_dist_parity2.txt",header=T)
str(ran)
hist(ran$dist, breaks =10)
# check excel sheets to calculate distance between randon snps and parity modes gene vs. cadidate snps

### FIGURE S4 ###
### colour ###
# Plot candidate SNPS colour
params <-read.table("mlm_female_colour_p_adjust_19chr_re-ordered.txt",header=T)
str(params)
snps <- GRanges(seqnames = params$chr,ranges = IRanges(params$ps, width = 1), y=params$LogP)
#set colors
by_chr <- c("gray40", "gray80")
#plot chromosomes
kp <- plotKaryotype(genome=data.frame(chromo_vec, length_vec),plot.type = 4)
# plot regions
kpRect(kp, data = cand.regions, y0=0, y1=1, col="coral3", border=NA, r0=0, r1=1)
# plot SNP p-values
kpAxis(kp, ymin = 0, ymax = 10, numticks = 11, col="#666666", cex=1, r0=0, r1=1)
kpPoints(kp, data=snps,col=colByChr(snps,by_chr), pch=16, cex=0.75, ymax=10, r0=0, r1=1)
### dots ###
# Plot candidate SNPS dots
params <-read.table("mlm_female_dots_p_adjust_19chr_re-ordered.txt",header=T)
# Plot candidate SNPS colour
snps <- GRanges(seqnames = params$chr,ranges = IRanges(params$ps, width = 1), y=params$LogP)
#plot chromosomes
kp <- plotKaryotype(genome=data.frame(chromo_vec, length_vec),plot.type = 4)
# plot regions
kpRect(kp, data = cand.regions, y0=0, y1=1, col="coral3", border=NA, r0=0, r1=1)
# plot SNP p-values
kpAxis(kp, ymin = 0, ymax = 10, numticks = 11, col="#666666", cex=1, r0=0, r1=1)
kpPoints(kp, data=snps,col=colByChr(snps,by_chr), pch=16, cex=0.75, ymax=10, r0=0, r1=1)

################### RNASeq analysis ################### 
setwd("C:/Users/hans_/Dropbox/Elmer Lab/Projects/Zootoca_colouration/06_re-submission_Mol_Ecol/R2_resubmission/enlighten")
# Set the prefix for each output file name
outputPrefix <- "ventral_DESeq2"
directory <- "C:/Users/hans_/Dropbox/Elmer Lab/Projects/Zootoca_colouration/06_re-submission_Mol_Ecol/R2_resubmission/enlighten"
#make table w/ sample info
sampleFiles<- c("ELT11930.counts",
                "ELT11941.counts",
                "ELT11944.counts",
                "ELT12074.counts",
                "ELT12078.counts")
sampleNames <- c("ELT11930","ELT11941","ELT11944","ELT12074","ELT12078")
sampleCondition <- c("oviparous","oviparous","oviparous","viviparous","viviparous")
sampleTable <- data.frame(sampleName = sampleNames, fileName = sampleFiles, condition = sampleCondition)
treatments = c("viviparous","oviparous")
#make DESeq object
ddsHTSeq <- DESeqDataSetFromHTSeqCount(sampleTable = sampleTable,
                                       directory = directory,
                                       design = ~ condition)
colData(ddsHTSeq)$condition <- factor(colData(ddsHTSeq)$condition,
                                      levels = treatments)
#guts
dds <- DESeq(ddsHTSeq)
#keep only genes with at least 20 counts
dds <- dds[rowSums(counts(dds)) >= 20,]
# Generate results table
DE_table <- results(dds, alpha = 0.05)
# Print summary of DE results
summary(DE_table)
mcols(DE_table, use.names = T)
# Print total number of gene that are significantly DE
length(DE_table$padj) #15800 genes in total
sum(DE_table$padj < 0.05, na.rm = TRUE) #1798 significantly expressed genes
#Arrange by descending p-value and make as data frame
DE_table <- DE_table[order(DE_table$pvalue),]
DE_table <- as.data.frame(DE_table)
#Table of log-transformed counts
log_counts <- as.data.frame(assay(rlog(dds)))

### DESEq2 ### 
log_counts <- tibble::rownames_to_column(log_counts, "gene")
DE_table <- tibble::rownames_to_column(DE_table, "gene")
#Add gene count info to DE_table to make a master_table
master_table <- inner_join(DE_table,log_counts)
master_table <- master_table %>% mutate(regulation = ifelse(log2FoldChange > 0, "up_in_ovi","up_in_vivi"))
#Table with only the significantly differentially expressed genes
DEG_table <- master_table %>% filter(padj < 0.05)
#write.csv(DEG_table, "DEG_genes.csv")

#### colour pathways ####
pteridine_genes <- c("GCHFR|MYCBP2|PCBD|\\bSPR\\b|TXNDC17|XDH|QDPR")
pteridine_pathway <- master_table %>% filter(str_detect(gene, regex(pteridine_genes, ignore_case = TRUE,))) %>% mutate(link_to_colour = "pteridine pathway")
carotenoid_genes <- c("SCARB1|BCO1|BCO2|DHRS3|DGAT|\\bLRAT\\b|ALDH|\\bADH|\\bRDH|RETSAT")
carotenoid_metabolism <- master_table %>% filter(str_detect(gene, regex(carotenoid_genes, ignore_case = TRUE))) %>% mutate(link_to_colour = "carotenoid metabolism")
carotenoid_metabolism <- carotenoid_metabolism %>% filter(gene != 'ADHFE1')
melanin_genes <- c("\\bTYR\\b|\\bTYRP1\\b|DDT|PMEL|OCA2|SLC24A5|SLC45A2")
melanin_pathway <- master_table %>% filter(str_detect(gene, regex(melanin_genes, ignore_case = TRUE))) %>% mutate(link_to_colour = "melanin pathway")
melanin_pathway$gene <- gsub("SLC45A2", "AIM1", melanin_pathway$gene)
all_pathways <- bind_rows(pteridine_pathway,melanin_pathway,carotenoid_metabolism)
all_pathways <- all_pathways %>% 
  select(log2FoldChange,padj,gene,link_to_colour,regulation,ELT11930,ELT11941,ELT11944,ELT12074,ELT12078) %>%
  gather("sample","log_transformed_counts",6:10) %>%
  mutate(reproductive_mode = ifelse(str_detect(sample,"ELT11"), "oviparous","viviparous")) %>%
  group_by(gene, reproductive_mode,link_to_colour,padj,regulation) %>%
  dplyr::summarise(mean_log_counts = mean(log_transformed_counts))
pteridine_table <- all_pathways %>% filter(link_to_colour == "pteridine pathway") %>% arrange(gene)
carotenoid_table <-all_pathways %>% filter(link_to_colour == "carotenoid metabolism") %>% arrange(gene)
melanin_table <-all_pathways %>% filter(link_to_colour == "melanin pathway") %>% arrange(gene)
melanin_table$gene <- factor(melanin_table$gene, levels = unique(melanin_table$gene))
carotenoid_table$gene <- factor(carotenoid_table$gene, levels = unique(carotenoid_table$gene))
pteridine_table$gene <- factor(pteridine_table$gene, levels = unique(pteridine_table$gene))

### FIGURE 3 ###
### PANEL A ###
## Volcano plot ##
volcano_table <- master_table %>% filter(gene != "MATN1")
volcano_table$gene <- as.character(volcano_table$gene)
pathways <- rbind(melanin_pathway,carotenoid_metabolism,pteridine_pathway)
pathways <- pathways %>% filter(padj < 0.05)
pathways$gene <- as.character(pathways$gene)
keyvals <- ifelse(volcano_table$padj >= 0.05, '#D3D3D3', 
                  ifelse(volcano_table$log2FoldChange < 0, '#DAC654',
                         ifelse(volcano_table$log2FoldChange > 0, '#E4C8BF',
                                '#D3D3D3')))
keyvals[is.na(keyvals)] <- '#D3D3D3'
names(keyvals)[keyvals == '#E4C8BF'] <- 'oviparous up'
names(keyvals)[keyvals == '#DAC654'] <- 'viviparous up'
names(keyvals)[keyvals == '#D3D3D3'] <- 'NS'
EnhancedVolcano(volcano_table,
                lab = volcano_table$gene,
                selectLab = pathways$gene,
                x = 'log2FoldChange',
                y = 'padj',
                pointSize = 3.0,
                labSize = 4.5,
                labCol = 'black',
                labFace = 'bold',
                boxedLabels = TRUE,
                colAlpha = 1,
                colCustom = keyvals,
                legendPosition = 'bottom',
                legendLabSize = 18,
                legendIconSize = 6.0,
                drawConnectors = TRUE,
                widthConnectors = 1.0,
                lengthConnectors = unit(0.01,"npc"),
                colConnectors = 'black',
                pCutoff = 0.05,
                FCcutoff = 2.0,
                title = NULL,
                subtitle = NULL,
                gridlines.major = FALSE,
                gridlines.minor = FALSE)
## Panel B ##
melanin.heatmap <- ggplot(data = melanin_table, 
                          mapping = aes(x = reproductive_mode,
                                        y = gene,
                                        fill = mean_log_counts)) +
  geom_tile(colour = "black", linewidth = 0.7,) +
  coord_fixed(ratio=0.1)+
  ylab(label = "Melanin Synthesis") +
  xlab(label = "") +
  scale_fill_distiller(name = "Mean\nlog2\ncounts", type = "div", palette = "RdYlBu")+
  scale_y_discrete(limits = rev(levels(melanin_table$gene)))+
  theme(text = element_text(face = "bold", colour = "#000000"),
        panel.background = element_blank(),
        axis.ticks = element_blank(),
        axis.text= element_text(size=14, color = "black"),
        axis.text.y = element_text(size=10, color = "black"),
        axis.text.x = element_blank(),
        axis.title=element_text(size=22,face="bold"))#,
#legend.position = "none")
melanin.heatmap
## Panel C ##
carotenoid.heatmap <- ggplot(data = carotenoid_table, 
                             mapping = aes(x = reproductive_mode,
                                           y = gene,
                                           fill = mean_log_counts)) +
  geom_tile(colour = "black", linewidth = 0.7) +
  coord_fixed(ratio = 0.1) +
  ylab(label = "Carotenoid Metabolism") +
  xlab(label = "") +
  scale_fill_distiller(name = "Mean\nlog2\ncounts", type = "div", palette = "RdYlBu")+
  scale_y_discrete(limits = rev(levels(carotenoid_table$gene)))+
  theme(text = element_text(face = "bold", colour = "#000000"),
        panel.background = element_blank(),
        axis.ticks = element_blank(),
        axis.text= element_text(size=14, color = "black"),
        axis.text.y = element_text(size=10, color = "black"),
        axis.title=element_text(size=22,face="bold"),
        legend.position = "none")
carotenoid.heatmap
## Panel D ##
pteridine.heatmap <- ggplot(data = pteridine_table, 
                            mapping = aes(x = reproductive_mode,
                                          y = gene,
                                          fill = mean_log_counts)) +
  geom_tile(colour = "black", linewidth = 0.75) +
  ylab(label = "Pteridine Synthesis") +
  xlab(label = "") +
  scale_fill_distiller(name = "Mean\nlog2\ncounts", type = "div", palette = "RdYlBu")+
  scale_y_discrete(limits = rev(levels(pteridine_table$gene)))+
  theme(text = element_text(face = "bold", colour = "#000000"),
        panel.background = element_blank(),
        axis.ticks = element_blank(),
        axis.text=element_text(size=14, color = "black"),
        axis.title=element_text(size=22,face="bold"))
pteridine.heatmap

### TABLE S7 ###
# Load tables from Higdon, C. W., Mitra, R. D. & Johnson, S. L. Gene expression analysis of zebrafish melanocytes, iridophores, and retinal pigmented epithelium reveals indicators of biological function and developmental origin. PLoS One 8, e67801 (2013).
iridophores <- read_xlsx("journal.pone.0067801.s017.XLSX",skip = 1)
iridophores_rpe <- read_xlsx("journal.pone.0067801.s015.XLSX",skip = 1)
iridophores_melanocytes <- read_xlsx("journal.pone.0067801.s014.XLSX",skip = 1)
iridophores <- iridophores %>%
  select(1,4)
names(iridophores) <- c("refseq","iridophore")
iridophores_rpe <- iridophores_rpe %>%
  select(1,4)
names(iridophores_rpe) <- c("refseq","iridophore")
iridophores_melanocytes <- iridophores_melanocytes %>%
  select(1,4)
names(iridophores_melanocytes) <- c("refseq","iridophore")
all_iridophores <- rbind(iridophores, iridophores_melanocytes) %>%
  rbind(., iridophores_rpe)
all_iridophores$gene <- gsub(".*\\((.*)\\).*", "\\1", all_iridophores$refseq)
all_iridophores <- all_iridophores %>% select(3)
all_iridophores$gene <- toupper(all_iridophores$gene)
DEG_iridophores = inner_join(DEG_table, all_iridophores)
#write.csv(DEG_iridophores, "DEG_iridophore_genes.csv")

### FIGURE 4 ### 
### PANEL A ###
allele_freq_diff <- read_xlsx("allele_freq_diff.xlsx")
# Function to process allele frequency differences for each gene
process_gene_data <- function(data, gene) {
  gene_data <- filter(data, GENE == gene)
  my_threshold <- quantile(gene_data$FREQ_DIFF, 0.975, na.rm = TRUE)
  gene_data$outlier <- gene_data$FREQ_DIFF > my_threshold
  sum_outliers <- sum(gene_data$outlier, na.rm = TRUE)
  return(list(data = gene_data, outliers = sum_outliers))
}
# List of genes
genes <- unique(allele_freq_diff$GENE)
# Process each gene
results <- lapply(genes, function(gene) process_gene_data(allele_freq_diff, gene))
# Extracting the number of outliers for each gene
outliers_count <- sapply(results, function(x) x$outliers)
names(outliers_count) <- genes
print(outliers_count)
# Filter out BCo2 as it was not significantly differentially expressed.
filtered_data <- filter(allele_freq_diff, GENE != "BCO2")
# Plotting
plot <- ggplot(filtered_data, aes(x = GENE, y = FREQ_DIFF, fill = REGION)) + 
  geom_boxplot() + 
  theme_classic()
plot

### PANEL B ###
dgat2_windowed100_fst <-read.delim("ovi_vs_vivi_windowed100.weir.fst")
dgat2_windowed100_fst$MEAN_FST <- as.numeric(dgat2_windowed100_fst$MEAN_FST)
dgat2_windowed100_fst <- dgat2_windowed100_fst %>% filter(MEAN_FST > 0)
quantile(dgat2_windowed100_fst$MEAN_FST, c(0.975, 0.995), na.rm = T)
# identify the 95% percentile
my_threshold_dgat2 <- quantile(dgat2_windowed100_fst$MEAN_FST, 0.975, na.rm = T)
# make an outlier column in the data.frame
dgat2_windowed100_fst <- dgat2_windowed100_fst %>% mutate(outlier = ifelse(MEAN_FST > my_threshold_dgat2, "outlier", "background"))
dgat2_windowed100_fst %>% group_by(outlier) %>% tally()
ggplot(dgat2_windowed100_fst, aes(BIN_START, MEAN_FST, colour = outlier)) +
  geom_point() +
  theme_classic() + theme(aspect.ratio = 1) +
  scale_colour_manual(name = NULL,values = c("black", "red")) +
  geom_hline(yintercept=my_threshold_dgat2, linetype="dashed", color = "black", size=0.1) +
  xlab("chr5 position") + ylab("Fst") + 
  geom_vline(xintercept = 6104446, size = 0.1) +
  geom_vline(xintercept = 6104561, size = 0.1) +
  geom_vline(xintercept = 6104600, size = 0.1) +
  geom_vline(xintercept = 6128262, size = 0.1) +
  geom_vline(xintercept = 6128381, size = 0.1) +
  geom_vline(xintercept = 6134060, size = 0.1) +
  geom_vline(xintercept = 6134167, size = 0.1) +
  geom_vline(xintercept = 6134700, size = 0.1) +
  geom_vline(xintercept = 6134770, size = 0.1) +
  geom_vline(xintercept = 6139289, size = 0.1) +
  geom_vline(xintercept = 6139493, size = 0.1) +
  geom_vline(xintercept = 6142590, size = 0.1) +
  geom_vline(xintercept = 6142764, size = 0.1) +
  geom_vline(xintercept = 6144011, size = 0.1) +
  geom_vline(xintercept = 6144213, size = 0.1) +
  geom_vline(xintercept = 6146001, size = 0.1) +
  geom_vline(xintercept = 6146155, size = 0.1) +
  geom_vline(xintercept = 6148503, size = 0.1)

### PANEL C ###
pmel_windowed100_fst <-read.delim("ovi_vs_vivi_windowed100.windowed.weir_pmel.fst")
pmel_windowed100_fst$MEAN_FST <- as.numeric(pmel_windowed100_fst$MEAN_FST)
pmel_windowed100_fst <- pmel_windowed100_fst %>% filter(MEAN_FST > 0)
quantile(pmel_windowed100_fst$MEAN_FST, c(0.975, 0.995), na.rm = T)
# identify outliers
my_threshold_pmel <- quantile(pmel_windowed100_fst$MEAN_FST, 0.975, na.rm = T)
# make an outlier column in the data.frame
pmel_windowed100_fst <- pmel_windowed100_fst %>% mutate(outlier = ifelse(MEAN_FST > my_threshold_pmel, "outlier", "background"))
pmel_windowed100_fst %>% group_by(outlier) %>% tally()
ggplot(pmel_windowed100_fst, aes(BIN_START, MEAN_FST, colour = outlier)) + 
  geom_point() +
  theme_classic() + theme(aspect.ratio = 1) +
  scale_colour_manual(name = NULL,values = c("black", "red")) + 
  geom_hline(yintercept=my_threshold_pmel, linetype="dashed", color = "black", size=0.1) +
  xlab("chr2 position") + ylab("Fst") + 
  geom_vline(xintercept = 17723922, size = 0.1) +
  geom_vline(xintercept = 17724117, size = 0.1) +
  geom_vline(xintercept = 17724276, size = 0.1) + 	
  geom_vline(xintercept = 17725683, size = 0.1) +
  geom_vline(xintercept = 17725773, size = 0.1) +
  geom_vline(xintercept = 17726123, size = 0.1) +
  geom_vline(xintercept = 17726325, size = 0.1) +
  geom_vline(xintercept = 17727092, size = 0.1) +
  geom_vline(xintercept = 17727185, size = 0.1) +
  geom_vline(xintercept = 17727965, size = 0.1) +
  geom_vline(xintercept = 17728126, size = 0.1) +
  geom_vline(xintercept = 17728831, size = 0.1) +
  geom_vline(xintercept = 17729271, size = 0.1) +
  geom_vline(xintercept = 17730866, size = 0.1) +
  geom_vline(xintercept = 17731312, size = 0.1) +
  geom_vline(xintercept = 17732270, size = 0.1) +
  geom_vline(xintercept = 17732431, size = 0.1) +
  geom_vline(xintercept = 17733628, size = 0.1) +
  geom_vline(xintercept = 17733768, size = 0.1) +
  geom_vline(xintercept = 17734370, size = 0.1) +
  geom_vline(xintercept = 17734516, size = 0.1) +
  geom_vline(xintercept = 17734614, size = 0.1) +
  geom_vline(xintercept = 17734748, size = 0.1) +
  geom_vline(xintercept = 17740438, size = 0.1) +
  geom_vline(xintercept = 17740568, size = 0.1) + 	
  geom_vline(xintercept = 17740504, size = 0.1)

### PANEL D ###
### Genotyping candidate SNP ###
data <- read.csv("chr5_6100408.csv",header=TRUE)
str(data)
boxplot(phenotype_hue~genotype, data = data)
# remove outliers  
boxplot(data$phenotype_hue, plot=FALSE)$out
outliers <- boxplot(data$phenotype_hue, plot=FALSE)$out
x<-data
x<- x[-which(x$phenotype_hue %in% outliers),]
# plot again without outlier
boxplot(phenotype_hue~genotype, data = x)

################### REPRODUCTIVE TRAIT ANALYSIS ################### 
setwd("C:/Users/hans_/Dropbox/Elmer Lab/Projects/Zootoca_colouration/06_re-submission_Mol_Ecol/R2_resubmission/enlighten")
colour_repro <- read.csv("colour_vs_genetics_repro_traits_for_PCA_no_hybrids_Q_corr.csv", header=TRUE)
str(colour_repro)
colour_repro$N_laid<-as.numeric(colour_repro$N_laid)

### TABLE S3 ###
## Hue
# FINAL MODEL 
summary(glm(h~inc_days_x+N_laid+average_off_weight+prop_survival+RCM+ROM+CMS,data=colour_repro))
# Model simplification
summary(glm(h~inc_days_x+N_laid+average_off_weight+RCM+ROM+CMS,data=colour_repro))
summary(glm(h~inc_days_x+N_laid+average_off_weight+RCM+CMS,data=colour_repro))
summary(glm(h~inc_days_x+N_laid+average_off_weight+CMS,data=colour_repro))
summary(glm(h~inc_days_x+average_off_weight+CMS,data=colour_repro))
summary(glm(h~inc_days_x+CMS,data=colour_repro))
summary(glm(h~inc_days_x,data=colour_repro))
## Saturation
# FINAL MODEL 
summary(glm(s~inc_days_x+N_laid+average_off_weight+prop_survival+RCM+ROM+CMS,data=colour_repro))
# Model simplification
summary(glm(s~inc_days_x+average_off_weight+prop_survival+RCM+ROM+CMS,data=colour_repro))
summary(glm(s~inc_days_x+prop_survival+RCM+ROM+CMS,data=colour_repro))
summary(glm(s~inc_days_x+RCM+ROM+CMS,data=colour_repro))
summary(glm(s~inc_days_x+ROM+CMS,data=colour_repro))
summary(glm(s~inc_days_x+CMS,data=colour_repro))
summary(glm(s~inc_days_x,data=colour_repro))
## Ligthness
# FINAL MODEL 
summary(glm(l~inc_days_x+N_laid+average_off_weight+prop_survival+RCM+ROM+CMS,data=colour_repro))
# Model simplification
summary(glm(l~inc_days_x+N_laid+average_off_weight+RCM+ROM+CMS,data=colour_repro))
summary(glm(l~inc_days_x+N_laid+RCM+ROM+CMS,data=colour_repro))
summary(glm(l~inc_days_x+RCM+ROM+CMS,data=colour_repro))
summary(glm(l~inc_days_x+RCM+CMS,data=colour_repro))
summary(glm(l~inc_days_x+CMS,data=colour_repro))
summary(glm(l~inc_days_x,data=colour_repro))
## PC 1
# FINAL MODEL 
summary(glm(PC1~inc_days_x+N_laid+average_off_weight+prop_survival+RCM+ROM+CMS,data=colour_repro))
# model simplification
summary(glm(PC1~inc_days_x+average_off_weight+prop_survival+RCM+ROM+CMS,data=colour_repro))
summary(glm(PC1~inc_days_x+prop_survival+RCM+ROM+CMS,data=colour_repro))
summary(glm(PC1~inc_days_x+prop_survival+RCM+ROM,data=colour_repro))
summary(glm(PC1~inc_days_x+RCM+ROM,data=colour_repro))
summary(glm(PC1~inc_days_x+ROM,data=colour_repro))
summary(glm(PC1~inc_days_x,data=colour_repro))
